Welcome to |project| documentation!
===================================

.. include:: ../README.rst
   :start-line: 25
   :end-line: 40

You can find the source code on `Github`_.

.. _Github: https://github.com/papr/pupil-core-network-client

.. toctree::
   :maxdepth: 1

   examples
   api
   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
